@@ -1,8 +1,7 @@
 #[cfg(feature = "config")]
 use ::config_crate::{ConfigError, Environment};
-use deadpool::managed::PoolConfig;
 
-use crate::{Pool, RedisResult};
+use crate::{Pool, PoolConfig, RedisResult};
 
 /// Configuration object. By enabling the `config` feature you can
 /// read the configuration using the [`config`](https://crates.io/crates/config)
@@ -40,6 +39,10 @@ pub struct Config {
 impl Config {
     /// Create configuration from environment variables.
     #[cfg(feature = "config")]
+    #[deprecated(
+        since = "0.7.0",
+        note = "Please embed this structure in your own config structure and use `config::Config` directly."
+    )]
     pub fn from_env(prefix: &str) -> Result<Self, ConfigError> {
         let mut cfg = ::config_crate::Config::new();
         cfg.merge(Environment::with_prefix(prefix))?;
